pub fn graph_predict(
graph: &Graph,
catalog: &NodeCatalog,
x: &Value,
cache: Arc<dyn CacheStore>,
) -> Result<Value>Expand description
Compile in Inference mode and execute, returning the output.
pub fn graph_predict(
graph: &Graph,
catalog: &NodeCatalog,
x: &Value,
cache: Arc<dyn CacheStore>,
) -> Result<Value>Compile in Inference mode and execute, returning the output.