pub fn graph_run(
graph: &Graph,
catalog: &NodeCatalog,
mode: CompileMode,
cache: Arc<dyn CacheStore>,
) -> Result<HashMap<String, Value>>Expand description
Compile and execute a graph, returning all node outputs.
pub fn graph_run(
graph: &Graph,
catalog: &NodeCatalog,
mode: CompileMode,
cache: Arc<dyn CacheStore>,
) -> Result<HashMap<String, Value>>Compile and execute a graph, returning all node outputs.