Module pruner

Module pruner 

Early stopping strategies for optimization studies.

A Pruner decides whether a trial should be stopped based on intermediate metric values. Implementations: MedianPruner, PercentilePruner.

Structs

MedianPruner
Prune if current value is below the median of completed trials at the same step.
PercentilePruner
Prune if current value is below the given percentile.
TrialMetricHistory
A completed trial’s metric history (for comparing against).

Traits

Pruner
A pruner decides whether to stop a trial early based on intermediate metrics.