pub struct TieredCache { /* private fields */ }Expand description
Multi-level cache with automatic promotion.
Checks tiers in order: Memory → Local → (Remote, future). On a hit in a lower tier, promotes the entry to faster tiers.
Implementations
Sourceimpl TieredCache
impl TieredCache
Sourcepub fn new(tiers: Vec<(CacheTier, Box<dyn CacheStore>)>) -> Self
pub fn new(tiers: Vec<(CacheTier, Box<dyn CacheStore>)>) -> Self
Create a tiered cache from a list of (tier, store) pairs. Tiers should be ordered fastest-first.
Sourcepub fn memory_and_local(
memory: Box<dyn CacheStore>,
local: Box<dyn CacheStore>,
) -> Self
pub fn memory_and_local( memory: Box<dyn CacheStore>, local: Box<dyn CacheStore>, ) -> Self
Create a two-level cache: Memory + Local.