pub fn graph_predict(
graph: &Graph,
library: &FilterLibrary,
x: &Value,
cache: &dyn CacheStore,
) -> Result<Value>Expand description
Compile in Inference mode and execute, returning the last leaf’s output.
pub fn graph_predict(
graph: &Graph,
library: &FilterLibrary,
x: &Value,
cache: &dyn CacheStore,
) -> Result<Value>Compile in Inference mode and execute, returning the last leaf’s output.