pub fn graph_run(
graph: &Graph,
library: &FilterLibrary,
mode: CompileMode,
cache: &dyn CacheStore,
) -> Result<HashMap<String, Value>>Expand description
Compile and execute a graph, returning all node outputs.
pub fn graph_run(
graph: &Graph,
library: &FilterLibrary,
mode: CompileMode,
cache: &dyn CacheStore,
) -> Result<HashMap<String, Value>>Compile and execute a graph, returning all node outputs.